@@ -924,3 +924,13 @@ class HdDB:
             self.execute("ROLLBACK;")
             logger.error(f"Error clearing values in column: {e}")
             raise QueryError(f"Error clearing values in column: {e}")
+    
+    @attach_motherduck
+    def get_tables(self, org: str, db: str):
+        try:
+            query = f'SELECT id FROM "{org}__{db}".hd_tables'
+            result = self.execute(query).fetchall()
+            return [row[0] for row in result]
+        except (duckdb.Error, Exception) as e:
+            logger.error(f"Error fetching tables: {e}")
+            raise QueryError(f"Error fetching tables: {e}")
